@@ -26,7 +26,7 @@ import sys
 import gammu
 
 
-def main():
+def main() -> None:
     if len(sys.argv) != 3:
         print("This requires two parameters: memory_type and backup file (eg. vcard)!")
         sys.exit(1)
