@@ -19,8 +19,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-"""Sample script to show how to get SMSD status"""
-
+"""Sample script to show how to get SMSD status."""
 
 import gammu.smsd
 
